@@ -83,7 +83,9 @@ class AtriumResponse:
 
     def error_string(self):
         """ return the errors from the response as one string"""
-        return "\n".join(self._errors)
+        if self._errors:
+            return "\n".join(self._errors)
+        return ''
 
     def resources(self):
         """ return the resources from the last call """
