@@ -3,6 +3,7 @@
 import json
 import requests
 from ..atrium_response import AtriumResponse
+from ..endpoints import get_endpoints
 
 class DatacoreAPI:
     """ A class to handle the connection to AtriumSports Datacore """
@@ -53,7 +54,10 @@ class DatacoreAPI:
         """ generate an auth token """
         self._auth_token = ''
         self._auth_error = ''
-        auth_url = self._get_url('auth')
+        auth_url = get_endpoints(self._options.get('environment'), 'auth')
+        if not auth_url:
+            self._auth_error = 'Invalid environment option'
+            return None
         auth_data = {
             'credentialId': self._options.get('credential_id', ''),
             'credentialSecret': self._options.get('credential_secret', ''),
@@ -90,10 +94,14 @@ class DatacoreAPI:
             return self._return_error('Authentication Error: {}'.format(self._auth_error))
         call_headers['Authorization'] = "Bearer {}".format(token)
         call_headers['Content-Type'] = "application/json"
+        endpoint_url = get_endpoints(self._options.get('environment'), 'api')
+        if not endpoint_url:
+            return self._return_error('Invalid environment option')
         url = "{}/v{}/{}{}".format(
-            self._get_url('api'),
+            endpoint_url,
             self._options.get('version'),
-            self._options.get('sport'), url
+            self._options.get('sport'),
+            url
         )
         self._resources = {}
         kwargs['limit'] = self._get_limit(limit)
@@ -131,7 +139,7 @@ class DatacoreAPI:
             response = self._make_request(method, url, **kwargs)
             return AtriumResponse(response)
         except requests.exceptions.RequestException as err:
-            return self._return_error(err)
+            return self._return_error(str(err))
         return None
 
     @staticmethod
@@ -155,28 +163,6 @@ class DatacoreAPI:
             response = requests.delete(url, headers=headers, data=body)
         return response
 
-    def _get_url(self, url_type):
-        """ return urls for the atriumsports environments """
-        # Can we handle localhost?????
-        envs = {
-            'auth': {
-                'production': 'https://token.prod.cloud.atriumsports.com/v1/oauth2/rest/token',
-                'nonprod': 'https://token.nonprod.cloud.atriumsports.com/v1/oauth2/rest/token',
-                'sandpit': 'https://token.sandpit.cloud.atriumsports.com/v1/oauth2/rest/token',
-                'localhost': 'http://localhost:XXXX',
-            },
-            'api': {
-                'production': 'https://api.dc.prod.cloud.atriumsports.com',
-                'nonprod': 'https://api.dc.nonprod.cloud.atriumsports.com',
-                'sandpit': 'https://api.dc.sandpit.cloud.atriumsports.com',
-                'localhost': 'http://localhost:XXXX',
-            }
-        }
-        if not envs.get(url_type):
-            return None
-        url = envs[url_type].get(self._options.get('environment')) or ''
-        return url
-
     @staticmethod
     def _return_error(error):
         """ Return an error response """
