@@ -86,6 +86,9 @@ class DatacoreStreamingAPI:
         """ generate an auth token """
         self._auth_data = ''
         auth_url = get_endpoints(self._options.get('environment'), 'streamauth')
+        if not auth_url:
+            self._error = 'Invalid environment option'
+            return True
         auth_data = {
             'credentialId': self._options.get('credential_id', ''),
             'credentialSecret': self._options.get('credential_secret', ''),
@@ -114,7 +117,7 @@ class DatacoreStreamingAPI:
             response = requests.post(url, data=body)
             return AtriumResponse(response)
         except requests.exceptions.RequestException as err:
-            return self._return_error(err)
+            return self._return_error(str(err))
         return None
 
     def _build_scope_matrix(self):
