@@ -2,6 +2,15 @@
 
 def get_endpoints(environment, url_type):
     """ return urls for the atriumsports environments """
+
+    # add some extra mapping
+    fix_mapping = {
+        'prod': 'production',
+        'uat': 'nonprod',
+        'dev': 'sandpit',
+        'test': 'sandpit',
+    }
+    environment = fix_mapping.get(environment, environment)
     envs = {
         'auth': {
             'production': 'https://token.prod.cloud.atriumsports.com/v1/oauth2/rest/token',
